@@ -10,13 +10,13 @@ test_that("getWaitTimeSum  works as expected for sum of constant hazards", {
 test_that("getWaitTimeSum  works as expected for sum of hazards (entry = 0)", {
   U <- c(0.23, 0.86)
   actual <- getWaitTimeSum(U, haz1 = 0.8, haz2 = 1.2, p1 = 1.5, p2 = 0.7, entry = c(0, 0))
-  expected <- c((0.8 * actual[1])^1.5 + (1.2 * actual[1])^0.7, (0.8 * actual[2])^1.5 + (1.2 * actual[2])^0.7)
+  expected <- c(0.8 * actual[1]^1.5 + 1.2 * actual[1]^0.7, 0.8 * actual[2]^1.5 + 1.2 * actual[2]^0.7)
   expect_equal(-log(1 - U), expected)
 })
 
 test_that("getWaitTimeSum  works as expected for sum of hazards (entry != 0)", {
   U <- 0.4
   actual <- getWaitTimeSum(U, haz1 = 0.8, haz2 = 1.2, p1 = 1.5, p2 = 0.7, entry = 5)
-  expected <- (0.8 * (actual + 5))^1.5 - (0.8 * 5)^1.5 - (1.2 * 5)^0.7 + (1.2 * (actual + 5))^0.7
+  expected <- 0.8 * (actual + 5)^1.5 - 0.8 * 5^1.5 - 1.2 * 5^0.7 + 1.2 * (actual + 5)^0.7
   expect_equal(-log(1 - U), expected)
 })
